
Installation
============

In a virtual environment, install by issuing the command:

  .. code-block:: console

    pip install cx_Freeze --upgrade

Without virtual environment, depending on the system:

  .. code-block:: console

    python -m pip install cx_Freeze --upgrade

or

  .. code-block:: console

    python3 -m pip install cx_Freeze --upgrade

or download directly from `PyPI <https://pypi.org/project/cx_Freeze>`_.


Source code
-----------

You can download and extract the source code found on
`Github <https://github.com/marcelotduarte/cx_Freeze>`__
to do a a manual installation.

Installing from source requires ``setuptools``. This is installed
automatically in virtual environments.

The following steps are needed:

  .. code-block:: console

    python setup.py build
    python setup.py install

or

  .. code-block:: console

    python setup.py develop


Issue tracking on `Github <https://github.com/marcelotduarte/cx_Freeze/issues>`_.
